{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bwa-mem-PE.cwl",
            "label": "bwa-mem-PE-0.7.12",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biocontainers/bwa:v0.7.12_cv3"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6300
                }
            ],
            "baseCommand": [
                "bwa",
                "mem"
            ],
            "inputs": [
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/reference",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "FastA file for reference genome",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ]
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/RG_ID",
                    "type": "string",
                    "doc": "Read group identifier (ID) in RG line"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/RG_PL",
                    "type": "string",
                    "doc": "Platform/technology used to produce the read (PL) in RG line"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/RG_PU",
                    "type": "string",
                    "doc": "Platform Unit (PU) in RG line"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/RG_LB",
                    "type": "string",
                    "doc": "DNA preparation library identifier (LB) in RG line"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/RG_SM",
                    "type": "string",
                    "doc": "Sample (SM) identifier in RG line"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/fq1",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FastQ file from next-generation sequencers"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/fq2",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "FastQ file from next-generation sequencers"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/nthreads",
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-t",
                        "position": 3
                    },
                    "doc": "number of cpu cores to be used"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/outprefix",
                    "type": "string"
                }
            ],
            "stdout": "$(inputs.outprefix).sam",
            "stderr": "$(inputs.outprefix).sam.log",
            "arguments": [
                {
                    "position": 1,
                    "prefix": "-K",
                    "valueFrom": "10000000"
                },
                {
                    "position": 2,
                    "prefix": "-R",
                    "valueFrom": "@RG\tID:$(inputs.RG_ID)\tPL:$(inputs.RG_PL)\tPU:$(inputs.RG_PU)\tLB:$(inputs.RG_LB)\tSM:$(inputs.RG_SM)"
                }
            ],
            "outputs": [
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/sam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).sam"
                    }
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.12/log",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).sam.log"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard-SortSam.cwl",
            "label": "picard-SortSam-2.10.6",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/picard:2.10.6--py27_0"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6300
                }
            ],
            "baseCommand": [
                "java",
                "-jar",
                "/usr/local/share/picard-2.10.6-0/picard.jar",
                "SortSam"
            ],
            "inputs": [
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/sam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "position": 1
                    },
                    "doc": "input SAM alignment file"
                },
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/outprefix",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/bam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).bam"
                    }
                },
                {
                    "id": "#picard-SortSam.cwl/picard-SortSam-2.10.6/log",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).bam.log"
                    }
                }
            ],
            "stderr": "$(inputs.outprefix).bam.log",
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "OUTPUT=$(inputs.outprefix).bam"
                },
                {
                    "position": 3,
                    "valueFrom": "TMP_DIR=$(inputs.outprefix).bam.temp"
                },
                {
                    "position": 4,
                    "valueFrom": "SORT_ORDER=coordinate"
                },
                {
                    "position": 5,
                    "valueFrom": "COMPRESSION_LEVEL=1"
                },
                {
                    "position": 6,
                    "valueFrom": "VALIDATION_STRINGENCY=LENIENT"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#fastqPE2bam.cwl",
            "label": "fastqPE2bam",
            "inputs": [
                {
                    "type": "string",
                    "doc": "Read group identifier (ID) in RG line",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/RG_ID"
                },
                {
                    "type": "string",
                    "doc": "DNA preparation library identifier (LB) in RG line",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/RG_LB"
                },
                {
                    "type": "string",
                    "doc": "Platform/technology used to produce the read (PL) in RG line",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/RG_PL"
                },
                {
                    "type": "string",
                    "doc": "Platform Unit (PU) in RG line",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/RG_PU"
                },
                {
                    "type": "string",
                    "doc": "Sample (SM) identifier in RG line",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/RG_SM"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "doc": "FastQ file from next-generation sequencers",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/fq1"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "doc": "FastQ file from next-generation sequencers",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/fq2"
                },
                {
                    "type": "int",
                    "doc": "number of cpu cores to be used",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/nthreads"
                },
                {
                    "type": "string",
                    "doc": "Output prefix name",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/outprefix"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "doc": "FastA file for reference genome",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/reference"
                }
            ],
            "steps": [
                {
                    "label": "bwa_mem_PE",
                    "doc": "Mapping onto reference using BWA MEM",
                    "run": "#bwa-mem-PE.cwl",
                    "in": [
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/RG_ID",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/RG_ID"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/RG_LB",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/RG_LB"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/RG_PL",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/RG_PL"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/RG_PU",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/RG_PU"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/RG_SM",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/RG_SM"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/fq1",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/fq1"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/fq2",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/fq2"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/nthreads",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/nthreads"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/outprefix",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/outprefix"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/reference",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/reference"
                        }
                    ],
                    "out": [
                        "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/sam",
                        "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/log"
                    ],
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE"
                },
                {
                    "label": "picard_SortSam",
                    "doc": "Sort sam file and save as bam file",
                    "run": "#picard-SortSam.cwl",
                    "in": [
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/outprefix",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/picard_SortSam/outprefix"
                        },
                        {
                            "source": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/sam",
                            "id": "#fastqPE2bam.cwl/fastqPE2bam/picard_SortSam/sam"
                        }
                    ],
                    "out": [
                        "#fastqPE2bam.cwl/fastqPE2bam/picard_SortSam/bam",
                        "#fastqPE2bam.cwl/fastqPE2bam/picard_SortSam/log"
                    ],
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/picard_SortSam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputSource": "#fastqPE2bam.cwl/fastqPE2bam/picard_SortSam/bam",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#fastqPE2bam.cwl/fastqPE2bam/picard_SortSam/log",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/bam_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "outputSource": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/sam",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/sam"
                },
                {
                    "type": "File",
                    "outputSource": "#fastqPE2bam.cwl/fastqPE2bam/bwa_mem_PE/log",
                    "id": "#fastqPE2bam.cwl/fastqPE2bam/sam_log"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": [
                            {
                                "type": "record",
                                "fields": [
                                    {
                                        "type": "string",
                                        "name": "#main/inputSamples/RG_ID"
                                    },
                                    {
                                        "type": "string",
                                        "name": "#main/inputSamples/RG_LB"
                                    },
                                    {
                                        "type": "string",
                                        "name": "#main/inputSamples/RG_PL"
                                    },
                                    {
                                        "type": "string",
                                        "name": "#main/inputSamples/RG_PU"
                                    },
                                    {
                                        "type": "string",
                                        "name": "#main/inputSamples/RG_SM"
                                    },
                                    {
                                        "type": "File",
                                        "name": "#main/inputSamples/fq1"
                                    },
                                    {
                                        "type": "File",
                                        "name": "#main/inputSamples/fq2"
                                    },
                                    {
                                        "type": "string",
                                        "name": "#main/inputSamples/outprefix"
                                    }
                                ]
                            }
                        ]
                    },
                    "id": "#main/inputSamples"
                },
                {
                    "type": "int",
                    "id": "#main/nthreads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "doc": "FastA file for reference genome",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                }
            ],
            "steps": [
                {
                    "run": "#fastqPE2bam.cwl",
                    "in": [
                        {
                            "valueFrom": "$(inputs.inputSamples.RG_ID)",
                            "id": "#main/fastqPE2bam/RG_ID"
                        },
                        {
                            "valueFrom": "$(inputs.inputSamples.RG_LB)",
                            "id": "#main/fastqPE2bam/RG_LB"
                        },
                        {
                            "valueFrom": "$(inputs.inputSamples.RG_PL)",
                            "id": "#main/fastqPE2bam/RG_PL"
                        },
                        {
                            "valueFrom": "$(inputs.inputSamples.RG_PU)",
                            "id": "#main/fastqPE2bam/RG_PU"
                        },
                        {
                            "valueFrom": "$(inputs.inputSamples.RG_SM)",
                            "id": "#main/fastqPE2bam/RG_SM"
                        },
                        {
                            "valueFrom": "$(inputs.inputSamples.fq1)",
                            "id": "#main/fastqPE2bam/fq1"
                        },
                        {
                            "valueFrom": "$(inputs.inputSamples.fq2)",
                            "id": "#main/fastqPE2bam/fq2"
                        },
                        {
                            "source": "#main/inputSamples",
                            "id": "#main/fastqPE2bam/inputSamples"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/fastqPE2bam/nthreads"
                        },
                        {
                            "valueFrom": "$(inputs.inputSamples.outprefix)",
                            "id": "#main/fastqPE2bam/outprefix"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/fastqPE2bam/reference"
                        }
                    ],
                    "scatter": [
                        "#main/fastqPE2bam/inputSamples"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/fastqPE2bam/sam",
                        "#main/fastqPE2bam/sam_log",
                        "#main/fastqPE2bam/bam",
                        "#main/fastqPE2bam/bam_log"
                    ],
                    "id": "#main/fastqPE2bam"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fastqPE2bam/bam",
                    "id": "#main/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fastqPE2bam/bam_log",
                    "id": "#main/bam_log"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fastqPE2bam/sam",
                    "id": "#main/sam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fastqPE2bam/sam_log",
                    "id": "#main/sam_log"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "edam": "http://edamontology.org/"
    }
}
